﻿using System;
using System.IO;
using System.Windows;
using System.Windows.Input;
using Microsoft.Win32;
using Telerik.Windows.Controls;
using Telerik.Windows.Documents.Fixed.FormatProviders.Pdf;
using Telerik.Windows.Documents.Fixed.FormatProviders.Pdf.Export;
using Telerik.Windows.Documents.Fixed.Model;
using Telerik.Windows.Documents.Fixed.Model.ColorSpaces;
using Telerik.Windows.Documents.Fixed.Model.Editing;
using Telerik.Windows.Documents.Fixed.Model.Editing.Tables;
using Editing = Telerik.Windows.Documents.Fixed.Model.Editing;
using HorizontalAlignment = Telerik.Windows.Documents.Fixed.Model.Editing.Flow.HorizontalAlignment;

namespace ImageInTableCellPdfProcessing
{
    public class ExampleViewModel : ViewModelBase
    {
        public ExampleViewModel()
        {
            this.Save = new DelegateCommand(this.Export);
        }

        public ICommand Save { get; private set; }

        private Stream CompanyLogoImageStream
        {
            get
            {
                return FileHelper.GetSampleResourceStream("telerik.jpg");
            }
        }

        private void Export(object param)
        {
            PdfFormatProvider formatProvider = new PdfFormatProvider();
            formatProvider.ExportSettings.ImageQuality = ImageQuality.High;

            SaveFileDialog dialog = new SaveFileDialog();
            dialog.Filter = String.Format("{0} files|*.{1}", "Pdf", "pdf");

            if (dialog.ShowDialog() == true)
            {
                using (var stream = dialog.OpenFile())
                {
                    RadFixedDocument document = this.CreateDocument();
                    formatProvider.Export(document, stream);
                }
            }
        }

        private RadFixedDocument CreateDocument()
        {
            RadFixedDocument document = new RadFixedDocument();
            RadFixedPage page = document.Pages.AddPage();
            page.Size = new System.Windows.Size(792, 1128);
            FixedContentEditor editor = new FixedContentEditor(page);

            this.DrawTableContent(editor);

            return document;
        }

        private void DrawTableContent(FixedContentEditor editor)
        {
            RgbColor bordersColor = new RgbColor(149, 179, 215);
            Border border = new Border(1, Editing.BorderStyle.Single, bordersColor);

            Table table = new Table();
            table.Borders = new TableBorders(border);
            table.DefaultCellProperties.Borders = new TableCellBorders(border, border, border, border);
            table.DefaultCellProperties.Padding = new System.Windows.Thickness(2);

            TableRow imgRow = table.Rows.AddTableRow();
            TableCell imgCell = imgRow.Cells.AddTableCell();
            imgCell.Borders = new TableCellBorders(new Border(BorderStyle.None));
            Block headerBlock = imgCell.Blocks.AddBlock();
            headerBlock.HorizontalAlignment = HorizontalAlignment.Center;
            headerBlock.InsertImage(this.CompanyLogoImageStream);

            double top = 20;
            double left = 20;
            double width = 200;
            table.Draw(editor, new Rect(left, top, width, double.PositiveInfinity));
        }
    }
}